@@ -9,6 +9,7 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3(tr("Reading settings..."), tr("Abort"), 0, 100, this),
     colors()
 {
+    this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
     ui->scrollArea->setWidget(ui->widget);
 
@@ -28,6 +29,7 @@ MainWindow::MainWindow(QWidget *parent) :
     QRegExp regexer("^\\#[0-9a-fA-F]{6,6}$");
     progress3.setValue(35);
     QRegExp regexer_icon("^[0-9]{2,3}$");
+    QRegExp regexer_opaasi("^[0-9]{1,3}$");
     progress3.setValue(45);
     QRegExp regexer_book("^[0-9]{2,3}$");
     progress3.setValue(50);
@@ -45,7 +47,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->lineEdit->setValidator(new QRegExpValidator(regexer_icon, ui->lineEdit));
     ui->lineEdit_2->setValidator(new QRegExpValidator(regexer_book, ui->lineEdit_2));
     ui->Snap->setValidator(new QRegExpValidator(regexer_snap, ui->Snap));
-    ui->Opacity->setValidator(new QRegExpValidator(regexer_icon, ui->Opacity));
+    ui->Opacity->setValidator(new QRegExpValidator(regexer_opaasi, ui->Opacity));
     progress3.setValue(80);
     readgtkrc();
     progress3.setValue(100);
@@ -227,6 +229,34 @@ void MainWindow::readSettings()
 
 }
 
+void MainWindow::SetOpacity(QString imagefile, int opacity)
+{
+
+    QPixmap temp;
+    imagefile = QFileInfo(imagefile).symLinkTarget();
+    QString imagebackup = "/opt/theme-customizer/backups/" + imagefile;
+    // First of all, let's check if the backup exists
+    if ( !QFileInfo(imagefile).exists() && !QFileInfo(imagebackup).exists() ) {
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'No image found...!' uint32:0 string:'OK'");
+    return;
+    }
+    // QString imagebackup = "/opt/theme-customizer/backups/" + imagefile;
+    // Set image opacity using the original image we have created
+    temp = QPixmap(imagebackup);
+    QPixmap transparent(temp.size());
+    transparent.fill(Qt::transparent);
+    QPainter p(&transparent);
+    p.setCompositionMode(QPainter::CompositionMode_Source);
+    p.drawPixmap(0, 0, temp);
+    p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
+    p.fillRect(transparent.rect(), QColor(0, 0, 0, opacity));  // opacity value can be 0-255
+    p.end();
+    // Save the new image
+    transparent.save(imagefile);
+    // system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Image saved!' uint32:0 string:'OK'");
+
+}
+
 void MainWindow::on_pushButton_clicked()
 {
         QString checkboxstate;
@@ -255,20 +285,37 @@ void MainWindow::on_pushButton_clicked()
         arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
         QProcess *process = new QProcess(this);
         connect(process, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
-        process->start("/sbin/launchcustomizer", arguments);
+        process->start("/sbin/customizer", arguments);
         progress.show();
 
-
 }
 
 void MainWindow::processFinished(int)
 {
+    int opasity = ui->Opacity->text().toInt();
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Setting up widget opacities...'");
+    SetOpacity("/etc/hildon/theme/images/ApplicationShortcutApplet.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/CalendarAppletBackground.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/ContactsAppletFrame.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MapAppletButton.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MapAppletHead.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletHead.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletNext.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletPrevious.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/MediaPlayerAppletStopPlay.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/OviCenter.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/OviLeft.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/OviRight.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/RSSAppletHead.png", opasity);
+    SetOpacity("/etc/hildon/theme/images/WebShortcutAppletBackground.png", opasity);
 
     if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
-        system("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
+        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
         system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
-        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home && sleep 2 && run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
+        system("sleep 2");
+        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
         system("sleep 2 && killall hildon-status-menu");
         system("sleep 2 && killall systemui");
         system("sleep 2 && killall hildon-desktop");
@@ -276,8 +323,11 @@ void MainWindow::processFinished(int)
 
     }
 
-    progress.cancel();
-    oldfonts();
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
+    system("sleep 2");
+    system("reboot");
+//    progress.cancel();
+//    oldfonts();
 
 }
 
